@@ -7,22 +7,21 @@ import copy
 import base64
 import datetime
 import traceback
-from urllib import parse
+import uuid
 import _thread
 import asyncio  # Requerido
 from jaeger_client import Config
 from opentracing import Format
 from opentracing.ext import tags as ext_tags
-from flask import Flask
 from abc import abstractmethod, ABC
 from .options import Options
-from .types import TypesActions, Types
 from .Worker import Worker
 from .Fork import Fork
 from .ErrorMs import ErrorMs
 from .Util import validForksConf, getItemBy
 from .version_framework import version
 from http.server import BaseHTTPRequestHandler, HTTPServer
+from .types import TypesActions
 
 if os.environ.get('KAFKA', None):
     from .ms_base import KafkaBase as BaseClass
@@ -227,6 +226,37 @@ class Microservices(BaseClass, ABC):
         """
         return base64.b64encode(str.encode(json.dumps(json_in)))
 
+    def without_response(self, topic, data):
+        """
+            Metodo para el envio de una peticion a un topico, sin esperar
+            una respuesta del mismo.
+        """
+        self._send(topic, {
+            "metadata": {
+                "uuid": None,
+                "id_operacion": str(uuid.uuid4()),
+                "id_transaction": str(uuid.uuid4()),
+                "intents": 1,
+                "callback": None,
+                "callbacks": [],
+                "owner": self.__TOPIC__,
+                "uowner": self.__TOPIC__,
+                "uworker": "{}_WITHOUT_RESPONSE".format(self.__TOPIC__),
+                "worker": self.__TOPIC__,
+                "asynchronous": False,
+                "mtype": "WITHOUT_RESPONSE",
+                "bifurcacion": False,
+                "time": "",
+                "from": socket.gethostname(),
+                "method": "GET",
+                "deviceType": "",
+                "span": None,
+                "filters": None,
+            },
+            "data": data,
+            "headers": {}
+        }, str(uuid.uuid4()))
+
     def _message(self, msg):
         """
             Metodo que se encagra de procesar todos los
@@ -307,7 +337,7 @@ class Microservices(BaseClass, ABC):
                     # print('EXIT TIME : ', msg['metadata']['time'], ' ', diff)
                     pass
         except:
-            self.logs.error(
+            self.logs.warn(
                 'Ocurrior un error al momento de procesar el tiempo del mensaje')
 
         # Procesar el mensaje
@@ -363,21 +393,27 @@ class Microservices(BaseClass, ABC):
             # Ruta [SOLO NATST]
             id_route_nats = getItemBy('response.uuid', RESP)
 
-            # Enviar la respuesta
-            self.__response(
-                RESP.get('response', {}),
-                RESP.get('errorCode'),
-                span=span,
-                nats_route=id_route_nats,
-                errorResp=RESP.get('errorWorker', None),
-            )
+            if not msg['metadata']['mtype'] == 'WITHOUT_RESPONSE':
+                # Enviar la respuesta
+                self.__response(
+                    RESP.get('response', {}),
+                    RESP.get('errorCode'),
+                    span=span,
+                    nats_route=id_route_nats,
+                    errorResp=RESP.get('errorWorker', None),
+                )
+
         except ErrorMs as error:
             span.set_tag(ext_tags.ERROR, True)
             span.log_kv({'event': 'error', 'error.code': error.errorCode, 'error.message': self.___getErrorId(
                 error.errorCode), 'error.stack': traceback.format_exc()})
             self.logs.error(self.___getErrorId(error.errorCode))
-            self.__response(msg, error.errorCode, span=span, nats_route=msg.get(
-                'uuid', None), errorResp=RESP.get('errorWorker', None),)  # Enviar el error
+            # Validar si es async
+            if not msg['metadata']['mtype'] == 'WITHOUT_RESPONSE':
+                self.__response(
+                    msg, error.errorCode, span=span, nats_route=msg.get(
+                        'uuid', None), errorResp=RESP.get('errorWorker', None),
+                )  # Enviar el error
 
         except Exception as e:
             span.set_tag(ext_tags.ERROR, True)
@@ -385,8 +421,11 @@ class Microservices(BaseClass, ABC):
                 e), 'error.stack': traceback.format_exc()})
             self.logs.error(e)
             # Enviar el error
-            self.__response(msg, -99, span=span, nats_route=msg.get('uuid',
-                                                                    None), errorResp=RESP.get('errorWorker', None),)
+            if not msg['metadata']['mtype'] == 'WITHOUT_RESPONSE':
+                self.__response(
+                    msg, -99, span=span, nats_route=msg.get('uuid', None),
+                    errorResp=RESP.get('errorWorker', None),
+                )
 
         span.finish()
 
@@ -518,7 +557,7 @@ class Microservices(BaseClass, ABC):
                     "name": self.__TOPIC__,
                 })
 
-            #TOPIC_RESP = dataResponse['metadata']['worker']
+            # TOPIC_RESP = dataResponse['metadata']['worker']
         else:
             callbacks = getItemBy('metadata.callbacks', dataResponse)
             # Se obtiene el ultimo elemento agregado para responder a el
@@ -654,7 +693,7 @@ class Microservices(BaseClass, ABC):
     def __getMethod(self, meta):
         """
             Metodo para recuperar el metodo que se
-            ejecutara, segun los datos pasados en 
+            ejecutara, segun los datos pasados en
             el metada.
         """
         if meta.get('method', None) and (meta.get('uuid', None) and len(meta.get('uuid', '')) > 0):
